/* -----------------------------------------------------------------------------
| Copyright (c) Jupyter Development Team.
| Distributed under the terms of the Modified BSD License.
|----------------------------------------------------------------------------*/
import { ToolbarButton } from '@jupyterlab/apputils';
import { LabIcon } from '@jupyterlab/ui-components';
import { each } from '@lumino/algorithm';
import { PanelLayout, Widget } from '@lumino/widgets';
const CELL_MENU_CLASS = 'jp-cell-menu';
/**
 * Toolbar icon menu container
 */
export class CellMenu extends Widget {
    constructor(commands, items) {
        super();
        this._commands = commands;
        this.layout = new PanelLayout();
        this.addClass(CELL_MENU_CLASS);
        this._addButtons(items);
    }
    handleEvent(event) {
        switch (event.type) {
            case 'mousedown':
            case 'click':
                // Ensure the mouse event is not propagated on the cell.
                event.stopPropagation();
                break;
        }
    }
    /**
     * Handle `after-attach` messages for the widget.
     */
    onAfterAttach() {
        this.node.addEventListener('mousedown', this);
        this.node.addEventListener('click', this);
    }
    /**
     * Handle `before-detach` messages for the widget.
     */
    onBeforeDetach() {
        this.node.removeEventListener('mousedown', this);
        this.node.removeEventListener('click', this);
    }
    _addButtons(items) {
        each(this.children(), widget => {
            widget.dispose();
        });
        const layout = this.layout;
        items.forEach(entry => {
            var _a, _b;
            if (this._commands.hasCommand(entry.command)) {
                layout.addWidget(new ToolbarButton({
                    icon: LabIcon.resolve({ icon: entry.icon }),
                    className: `jp-cell-${(_a = entry.cellType) !== null && _a !== void 0 ? _a : 'all'}`,
                    onClickWithEvent: (e) => {
                        // Prevent propagation of this event in case the command causes the
                        // current cell to move. If the cell moves and the event propagates to the
                        // new cell, this may have an effect on the new cell.
                        void this._commands.execute(entry.command);
                        e.stopPropagation();
                    },
                    tooltip: (_b = entry.tooltip) !== null && _b !== void 0 ? _b : this._commands.label(entry.command)
                }));
            }
        });
    }
}
//# sourceMappingURL=cellmenu.js.map