import { ICellModel } from '@jupyterlab/cells';
import { DocumentRegistry } from '@jupyterlab/docregistry';
import { Notebook, NotebookPanel } from '@jupyterlab/notebook';
import { IObservableList, IObservableUndoableList } from '@jupyterlab/observables';
import { ISettingRegistry } from '@jupyterlab/settingregistry';
import { LabIcon } from '@jupyterlab/ui-components';
import { CommandRegistry } from '@lumino/commands';
import { IDisposable } from '@lumino/disposable';
/**
 * Icons for use in toolbar.
 *
 * These are copied from icon.ts, which is not part of the webpack bundle
 * because nothing is imported from it.
 */
export declare const addAboveIcon: LabIcon;
export declare const addBelowIcon: LabIcon;
export declare const deleteIcon: LabIcon;
export declare const duplicateIcon: LabIcon;
export declare const moveDownIcon: LabIcon;
export declare const moveUpIcon: LabIcon;
/**
 * Watch a notebook so that a cell toolbar appears on the active cell
 */
export declare class CellToolbarTracker implements IDisposable {
    constructor(panel: NotebookPanel, commands: CommandRegistry, settings: ISettingRegistry.ISettings | null);
    _onActiveCellChanged(notebook: Notebook): void;
    get isDisposed(): boolean;
    dispose(): void;
    /**
     * Callback to react to cells list changes
     *
     * @param cells List of notebook cells
     * @param changed Modification of the list
     */
    updateConnectedCells(cells: IObservableUndoableList<ICellModel>, changed: IObservableList.IChangedArgs<ICellModel>): void;
    private _addToolbar;
    private _getCell;
    private _findToolbarWidgets;
    private _removeToolbar;
    /**
     * Call back on settings changes
     */
    private _onSettingsChanged;
    private _changedEventCallback;
    private _resizeEventCallback;
    private _updateCellForToolbarOverlap;
    private _cellToolbarOverlapsContents;
    /**
     * Check for overlap between rendered Markdown and the cell toolbar
     *
     * @param activeCell A rendered MarkdownCell
     * @returns `true` if the first line of the output overlaps with the cell toolbar, `false` otherwise
     */
    private _markdownOverlapsToolbar;
    private _codeOverlapsToolbar;
    private _cellEditorWidgetLeft;
    private _cellEditorWidgetRight;
    private _cellToolbarLeft;
    private _commands;
    private _isDisposed;
    private _panel;
    private _previousActiveCell;
    private _settings;
}
/**
 * Widget extension that creates a CellToolbarTracker each time a notebook is
 * created.
 */
export declare class CellBarExtension implements DocumentRegistry.WidgetExtension {
    constructor(commands: CommandRegistry, settings: ISettingRegistry.ISettings | null);
    createNew(panel: NotebookPanel): IDisposable;
    private _commands;
    private _settings;
}
