import { ReactWidget } from '@jupyterlab/apputils';
import { LabIcon } from '@jupyterlab/ui-components';
/**
 * Toggle button properties
 */
export interface IToggleButtonProps {
    /**
     * Button class name
     */
    className?: (state: boolean) => string;
    /**
     * Button label
     */
    label?: (state: boolean) => string;
    /**
     * Button icon
     */
    icon?: (state: boolean) => LabIcon;
    /**
     * Button tooltip
     */
    tooltip?: (state: boolean) => string;
    /**
     * Button callback
     */
    onClick?: (state: boolean) => void;
    /**
     * Button enabled status
     */
    enabled?: (state: boolean) => boolean;
    /**
     * Trigger the button on the actual onClick event rather than onMouseDown.
     *
     * See note in ToolbarButtonComponent below as to why the default is to
     * trigger on onMouseDown.
     */
    actualOnClick?: boolean;
}
export declare class ToggleButton extends ReactWidget {
    protected props: IToggleButtonProps;
    /**
     * Creates a toolbar toggle button
     *
     * Initial state is false
     *
     * @param props props for underlying `ToolbarButton` component
     */
    constructor(props?: IToggleButtonProps);
    /**
     * Toggled button state
     */
    get toggled(): boolean;
    set toggled(value: boolean);
    render(): JSX.Element;
    protected _toggled: boolean;
}
