/* -----------------------------------------------------------------------------
| Copyright (c) Jupyter Development Team.
| Distributed under the terms of the Modified BSD License.
|----------------------------------------------------------------------------*/
import { addToolbarButtonClass, ReactWidget, ToolbarButtonComponent } from '@jupyterlab/apputils';
import React from 'react';
export class ToggleButton extends ReactWidget {
    /**
     * Creates a toolbar toggle button
     *
     * Initial state is false
     *
     * @param props props for underlying `ToolbarButton` component
     */
    constructor(props = {}) {
        super();
        this.props = props;
        this._toggled = false;
        addToolbarButtonClass(this);
    }
    /**
     * Toggled button state
     */
    get toggled() {
        return this._toggled;
    }
    set toggled(value) {
        if (value !== this._toggled) {
            this._toggled = value;
            this.update();
        }
    }
    render() {
        const p = {
            className: this.props.className
                ? this.props.className(this.toggled)
                : undefined,
            label: this.props.label ? this.props.label(this.toggled) : undefined,
            icon: this.props.icon ? this.props.icon(this.toggled) : undefined,
            tooltip: this.props.tooltip
                ? this.props.tooltip(this.toggled)
                : undefined,
            onClick: this.props.onClick
                ? () => {
                    this.toggled = !this.toggled;
                    this.props.onClick(this.toggled);
                }
                : undefined,
            enabled: this.props.enabled ? this.props.enabled(this.toggled) : undefined
        };
        return React.createElement(ToolbarButtonComponent, Object.assign({}, p));
    }
}
//# sourceMappingURL=toolbarbutton.js.map